;;;;;;;;;;;;; LUCA ALASIO - Scuola di Studi Superiori dell'Universit di Torino ;;;;;;;;;;;;;;;;;;;


extensions [gis]

globals [
         torino            ;; GIS dataset
         streets           ;; patches representing streets
         center-x          ;;
         center-y          ;; center of the map
         roads             ;; patches representing roadways
         mean-poll         ;; average pollution indicator
         mean-wait-time    ;; average time turtles stay at rest
         mean-motion-time  ;; average time turtles stay in motion
         mean-speed        ;; turtles'speed indicator
         total-cost        ;; cost of time spent waiting
         ]

patches-own
[
  street?       ;; true if the patch is part of a street.
  color-p       ;; indicates right hand traffic
  turtles-num   ;; number of turtles on the patch
  pollution     ;; amount of pollution on the patch
]

turtles-own
[ 
  speed         ;; the speed of the turtle
  wait-time     ;; the amount of time since the last time a turtle has moved
  motion-time   ;; the amount of time with positive speed
  color-c       ;; indicates right hand traffic
  
]


;; WORLD ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to setup
  clear-all
  ask patches [set pcolor white]
  set torino gis:load-dataset "torino/file.shp"
  draw
end

to draw
  clear-drawing
  setup-world-envelope
  gis:set-drawing-color gray + 1  gis:draw torino 1
  end

to setup-world-envelope
  gis:set-world-envelope gis:envelope-of torino
  let world gis:world-envelope
  let x0 (item 0 world + item 1 world) / 2  + center-x; center
  let y0 (item 2 world + item 3 world) / 2  + center-y
  let W0 zoom * (item 1 world - item 0 world) / 2 ; half-widths
  let H0 zoom * (item 3 world - item 2 world) / 2
  set world (list (x0 - W0) (x0 + W0) (y0 - H0) (y0 + H0))  
  gis:set-world-envelope world
end

to center-here
  while [not mouse-down?] [wait .01]
  set center-x center-x + (mouse-xcor * gis-patch-size)
  set center-y center-y + (mouse-ycor * gis-patch-size)
  draw
end

to-report gis-patch-size ;; note: assume width & height same
  let world gis:world-envelope
  report (item 1 world - item 0 world) / (max-pxcor - min-pxcor)
end

to zoom-in  set zoom max list .01 precision (zoom - .1) 2
  draw
end

to zoom-out set zoom min list 1.2 precision (zoom + .1) 2
  draw
end

to zoom-std
  set zoom 0.05
  draw
end

to move-right
  set center-x center-x + shift * gis-patch-size
  draw
end

to move-left
  set center-x center-x - shift * gis-patch-size
  draw
end

to move-up
  set center-y center-y + shift * gis-patch-size
  draw
end

to move-down
  set center-y center-y - shift * gis-patch-size
  draw
end

to display-streets-in-patches
  ask patches [ set pcolor black
                set street? true ]
  ask patches gis:intersecting torino
  [ set pcolor white
    set street? false ]

  set streets patches with  [street? = true]
  
end



;; STREETS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to draw-streets-E
ask streets
[ if ( [pcolor] of patch-at 1 0 = white and
       [pcolor] of patch-at 1 1 = white and
       [pcolor] of patch-at 1 -1 = white
    )
      [set pcolor red]
] 
end

to draw-streets-W
ask streets
[ if ( [pcolor] of patch-at -1 0 = white and
       [pcolor] of patch-at -1 1 = white and
       [pcolor] of patch-at -1 -1 = white
    )
      [set pcolor blue]
] 
end

to draw-streets-N
ask streets
[ if ( [pcolor] of patch-at 0 1 = white and
       [pcolor] of patch-at 1 1 = white and
       [pcolor] of patch-at -1 1 = white
    )
      [set pcolor yellow
  ]
] 
end

to draw-streets-S
ask streets
[ if ( [pcolor] of patch-at 0 -1 = white and
       [pcolor] of patch-at -1 -1 = white and
       [pcolor] of patch-at 1 -1 = white
    )
      [set pcolor green]
] 
end

to draw-streets  ;; set a different color in order to make roadways recognisable
  draw-streets-N
  draw-streets-S
  draw-streets-E
  draw-streets-W
  
  set roads streets with [ pcolor != black ]
  ask streets [set color-p pcolor]
end

to cancel-colors
  ask patches
   [ if street? = false [set pcolor white] ]
  ask streets
   [set pcolor black]
end


;; TURTLES ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to setup-cars
  set-default-shape turtles "car"
  create-turtles num-cars
  
  put-on-street
  ask turtles [set speed 1]
end

to put-on-street 
  ask turtles [move-to  one-of roads]
  
end


to go 
  
 if poll-flag = true 
  [
  ask streets [set turtles-num count turtles-on self]
  evaluate-pollution
  ]
 
 if plot-flag = true 
  [ do-plots ]
    
 ask turtles 
 [
    if color-p != black
    [set color-c color-p]
     
    let turtles-ahead turtles in-cone 2 45
     
     ifelse any? turtles-ahead 
         [ slow
           rt 7 + random-float 3 ]
         [speed-up]
         
     if ([pcolor] of patch-ahead 1 != white) and ([street?] of patch-ahead 1 = true)
            [fd 1]
     
    ifelse ([pcolor] of patch-ahead 1 = white) or ([street?] of patch-ahead 1 = false)
    [ lt 30 ]
       [
          ifelse (color-c = [color-p] of patch-at 1 0)
                  or
                 (color-c = [color-p] of patch-at 1 1)
                 or
                 (color-c = color-p)
                  
           [ speed-up
             if ([pcolor] of patch-ahead speed != white) and ([street?] of patch-ahead speed = true)
             [fd speed]
           ] 
           [ rt -15 + random-float 30
             speed-up
             if ([pcolor] of patch-ahead speed != white) and ([street?] of patch-ahead speed = true)
             [fd speed]    
            ]
        ]
      
     ifelse speed = 0
     [ set wait-time wait-time + 1 
       set motion-time 0]
     [ set wait-time 0
       set motion-time motion-time + 1]
    
        
 ]
tick
end

to slow
  if (speed > 0)
  [set speed speed - 1]
end

to speed-up
  let turtles-ahead turtles-at 0 1
  if ([pcolor] of patch-ahead 2 != white) and (not any? turtles-ahead) 
   [ set speed speed + 1]
end

to cancel-cars
  clear-turtles
    set total-cost 0
end

to add-cars
  set-default-shape turtles "car"
  create-turtles num-cars
  ask turtles [set speed 1
               move-to one-of streets]
end


;; POLUTION AND PLOTS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to evaluate-pollution

  ask streets
  [
    if turtles-num != 0
    [
      set pollution pollution  + abs ( random-normal (turtles-num * pollution-mean) (turtles-num * pollution-deviation) )
    ]

  ]

  diffuse pollution 0.7
  
  ask patches
  [     
    set pollution pollution / poll-dispersion
  ]
  
  if show-poll = true
  [show-pollution]
  
  
  set mean-poll mean [pollution] of patches
      
  set-current-plot "Average Pollution"
  set-current-plot-pen "mean-poll"
  plot mean-poll
  
end

to do-plots
  
  set mean-wait-time mean [wait-time] of turtles
  
  set-current-plot "Average Wait Time"
  set-current-plot-pen "mean-wait-time"
  plot mean-wait-time
  
  set total-cost total-cost + (count turtles with [speed = 0]) * (cost-of-working / 3600)
  
  set-current-plot "Waiting Time Cost"
  set-current-plot-pen "total-cost"
  plot total-cost
  
  set mean-motion-time mean [motion-time] of turtles
  
  set-current-plot "Average Motion Time"
  set-current-plot-pen "mean-motion-time"
  plot mean-motion-time
  
  set mean-speed mean [speed] of turtles
  
  set-current-plot "Average Speed"
  set-current-plot-pen "mean-speed"
  plot mean-speed
  
end

to show-pollution
  ask patches
  [
    if (pollution >= 0)
    [set pcolor 10 + pollution * 2 / 3]
  ]
end


to cancel-plots
  clear-all-plots
end

to cancel-pollution
  ask patches
  [set pollution 0]
end


;; OBSERVATION ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to inspect-car
  inspect turtle 1
   
   ask turtle 1
   [set pcolor cyan]
end

to map-car
   ask turtle 1
   [set pcolor cyan]
end

to cancel-cyan
ask streets
[if pcolor = cyan
  [set pcolor black]
]
end

to street-change-color
  ask turtles
  [ if pcolor < 9
    [set pcolor (pcolor + 0.2)]
  ]
end



to close-street-here
  while [not mouse-down?] [wait .01]
  let posx mouse-xcor
  let posy mouse-ycor
   ask patches
  [if distance patch posx posy < 2 
    [set pcolor white] ]
end

to open-street-here
  while [not mouse-down?] [wait .01]
  let posx mouse-xcor
  let posy mouse-ycor
  ask patches
  [if distance patch posx posy < 2 
    [set pcolor black] ]
end





;;;;;;;;;;;;; LUCA ALASIO - Scuola di Studi Superiori dell'Universit di Torino ;;;;;;;;;;;;;;;;;;;
@#$#@#$#@
GRAPHICS-WINDOW
398
7
1011
641
100
100
3.0
1
10
1
1
1
0
1
1
1
-100
100
-100
100
0
0
0
ticks

BUTTON
133
16
245
49
NIL
setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
100
230
219
263
zoom
zoom
.01
1.2
0.05
.01
1
NIL
HORIZONTAL

BUTTON
262
196
328
229
center
;show \"Click on point to move to center of view.\"\ncenter-here
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
218
230
276
263
NIL
draw
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
61
196
126
229
NIL
zoom-in
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
125
196
193
229
NIL
zoom-out\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
150
75
230
109
NIL
move-up
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
150
109
230
146
NIL
move-down
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
230
111
323
146
NIL
move-right
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
64
108
150
146
NIL
move-left
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
193
196
262
229
NIL
zoom-std
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
15
296
191
330
NIL
display-streets-in-patches
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
110
399
282
432
num-cars
num-cars
0
2000
1200
25
1
NIL
HORIZONTAL

BUTTON
16
460
106
494
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
16
399
106
432
NIL
setup-cars
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
100
147
274
180
shift
shift
0
30
29
1
1
NIL
HORIZONTAL

BUTTON
287
400
377
434
NIL
cancel-cars
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
15
531
109
565
NIL
inspect-car
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
16
345
107
379
NIL
draw-streets
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
286
345
375
379
NIL
cancel-colors
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
14
606
108
640
NIL
cancel-cyan
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
15
568
109
602
NIL
map-car
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
160
607
287
641
NIL
street-change-color
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
1267
132
1439
165
pollution-mean
pollution-mean
0
5
2.4
0.1
1
NIL
HORIZONTAL

SLIDER
1269
170
1441
203
pollution-deviation
pollution-deviation
0
2
0.6
0.1
1
NIL
HORIZONTAL

PLOT
1037
41
1237
191
Average Pollution
time
mean-poll
0.0
10.0
0.0
1.0
true
false
PENS
"mean-poll" 1.0 0 -16777216 true

BUTTON
1284
590
1382
624
NIL
cancel-plots
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
290
537
380
571
NIL
cancel-pollution
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
1040
360
1240
510
Average Wait Time
time
mean-wait-time
0.0
10.0
0.0
3.0
true
false
PENS
"mean-wait-time" 1.0 0 -16777216 true

SWITCH
177
517
285
550
poll-flag
poll-flag
0
1
-1000

PLOT
1245
361
1445
511
Average Motion Time
time
mean-motion-time
0.0
10.0
0.0
3.0
true
false
PENS
"mean-motion-time" 1.0 0 -16777216 true

PLOT
1244
208
1444
358
Average Speed
time
mean-speed
0.0
10.0
0.0
3.0
true
false
PENS
"mean-speed" 1.0 0 -16777216 true

BUTTON
1017
549
1145
584
NIL
close-street-here
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
1018
584
1146
619
NIL
open-street-here
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SWITCH
1284
538
1384
571
plot-flag
plot-flag
1
1
-1000

SLIDER
1269
44
1442
77
cost-of-working
cost-of-working
0
100
20
5
1
NIL
HORIZONTAL

PLOT
1040
208
1240
358
Waiting Time Cost
time
total -cost
0.0
10.0
0.0
20.0
true
false
PENS
"total-cost" 1.0 0 -16777216 true

SLIDER
1269
96
1442
129
poll-dispersion
poll-dispersion
1
2
1.05
0.01
1
NIL
HORIZONTAL

SWITCH
177
555
285
589
show-poll
show-poll
0
1
-1000

BUTTON
289
458
379
492
NIL
add-cars
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

@#$#@#$#@
WHAT IS IT?
-----------
This model uses GIS extension in order to simulate traffic in the city of Torino (Italy) and it shows how traffic conditions influence pollution in the city; in addition it is possible to approximate the amount of money lost due to traffic delays.


HOW IT WORKS
------------
Patches not intersecting the GIS represent streets and, of course, turtles (cars) can only move on these patches. Turtles are expected to "drive" on the right, speed is represented by the number of patches they go forward and it decreases if there are any other turtles ahead.
Each patch has an indicator of its pollution levels depending on the number of cars on it and pollution diffuses to other patches as time passes.
Each turtle shows speed, waiting time and motion time.


HOW TO USE IT
-------------
First of all setup allows to import the GIS, then it is possible to move on the map and choose different areas of the city of Torino; there is a zoom utility but it is recommended to set zoom between 0.05 and 0.08 before going on.
Display-streets-in-patches (a bit slow) makes the distinction between streets and buildings, while draw-streets draws roadways. Notice that it is possible to open or close parts of a street using close-street-here and open-street-here.
Setup-cars creates the selected number of turtles and Go makes them move.
Two buttons allow to follow one of the turtles and to change color to its path.
Two switches allow to consider pollution and to show its concentration on the map; notice that original colors can be brought back using cancel-colors.
Change-street-color makes streets fade at car passage.


THINGS TO NOTICE
----------------
It is advisable to follow this order in pressing buttons:
setup / display-streets-in-patches / draw-streets / setup-cars / go.


THINGS TO TRY
-------------
Sliders:

cost-of-working represents the average cost of an hour of work (in euros or dollars)

poll-dispersion, if positioned at 1.00 no pollution is dissipated, if positioned at 2.00 50% of pollution disappears

The pollution growth caused by cars is represented by a normal probability distribution with parameters pollution-mean and deviation-mean


CREDITS AND REFERENCES
----------------------

SantaFeStreets model -- http://backspaces.net/wiki/NetLogo_Bag_of_Tricks#NetLogo_GIS
Traffic Grid model -- Netlogo Library


@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
